==> jc-1.4.0.tar.gz: gnu/xml/dom/DomNSResolverContext.h <==
// class gnu.xml.dom.DomNSResolverContext

// class file dependencies
// @dep_class b56e5b61cf947b96 gnu_xml_dom_DomNSResolverContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNSResolverContext_H_
#define _JC_gnu_xml_dom_DomNSResolverContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Iterator$object;
struct _jc_org_w3c_dom_xpath_XPathNSResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$sub_refs	_jc_gnu_xml_dom_DomNSResolverContext$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs	_jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$refs	_jc_gnu_xml_dom_DomNSResolverContext$refs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$nonrefs	_jc_gnu_xml_dom_DomNSResolverContext$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$object	_jc_gnu_xml_dom_DomNSResolverContext$object;

typedef const struct _jc_gnu_xml_dom_DomNSResolverContext$vmethods	_jc_gnu_xml_dom_DomNSResolverContext$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNSResolverContext$vtable	_jc_gnu_xml_dom_DomNSResolverContext$vtable;
typedef const struct _jc_gnu_xml_dom_DomNSResolverContext$vtype	_jc_gnu_xml_dom_DomNSResolverContext$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNSResolverContext$method$_init$f055b516f3736345(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomNSResolverContext$method$getNamespaceURI$1d411b1177c7c9a9(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomNSResolverContext$method$getPrefix$647af1d6e022a9c4(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_dom_DomNSResolverContext$method$getPrefixes$2ee849be7ba35061(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *);
extern jboolean _jc_gnu_xml_dom_DomNSResolverContext$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_DomNSResolverContext$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *);
extern void _jc_gnu_xml_dom_DomNSResolverContext$method$remove$fd50149979e1f350(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$getNamespaceURI$1d411b1177c7c9a9;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$getPrefix$647af1d6e022a9c4;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$getPrefixes$2ee849be7ba35061;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNSResolverContext$vmethods {
	struct _jc_java_lang_String$object	*(*getNamespaceURI$1d411b1177c7c9a9)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*getPrefix$647af1d6e022a9c4)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getPrefixes$2ee849be7ba35061)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomNSResolverContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNSResolverContext$vmethods	gnu_xml_dom_DomNSResolverContext;
};

// Vtype
struct _jc_gnu_xml_dom_DomNSResolverContext$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNSResolverContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNSResolverContext$sub_refs {
	struct _jc_object	*resolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNSResolverContext$refs {
    _jc_gnu_xml_dom_DomNSResolverContext$sub_refs	gnu_xml_dom_DomNSResolverContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNSResolverContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs	gnu_xml_dom_DomNSResolverContext;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNSResolverContext$object {
	_jc_gnu_xml_dom_DomNSResolverContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNSResolverContext$vtype	*vtype;
	_jc_gnu_xml_dom_DomNSResolverContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNSResolverContext$vtype _jc_gnu_xml_dom_DomNSResolverContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNSResolverContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNSResolverContext$class_object;

#endif	/* _JC_gnu_xml_dom_DomNSResolverContext_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomNSResolverContext.h <==
// class gnu.xml.dom.DomNSResolverContext

// class file dependencies
// @dep_class b56e5b61cf947b96 gnu_xml_dom_DomNSResolverContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomNSResolverContext_H_
#define _JC_gnu_xml_dom_DomNSResolverContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Iterator$object;
struct _jc_org_w3c_dom_xpath_XPathNSResolver$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$sub_refs	_jc_gnu_xml_dom_DomNSResolverContext$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs	_jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$refs	_jc_gnu_xml_dom_DomNSResolverContext$refs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$nonrefs	_jc_gnu_xml_dom_DomNSResolverContext$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNSResolverContext$object	_jc_gnu_xml_dom_DomNSResolverContext$object;

typedef const struct _jc_gnu_xml_dom_DomNSResolverContext$vmethods	_jc_gnu_xml_dom_DomNSResolverContext$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNSResolverContext$vtable	_jc_gnu_xml_dom_DomNSResolverContext$vtable;
typedef const struct _jc_gnu_xml_dom_DomNSResolverContext$vtype	_jc_gnu_xml_dom_DomNSResolverContext$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNSResolverContext$method$_init$f055b516f3736345(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomNSResolverContext$method$getNamespaceURI$1d411b1177c7c9a9(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomNSResolverContext$method$getPrefix$647af1d6e022a9c4(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_DomNSResolverContext$method$getPrefixes$2ee849be7ba35061(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_dom_DomNSResolverContext$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_dom_DomNSResolverContext$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomNSResolverContext$method$remove$fd50149979e1f350(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$getNamespaceURI$1d411b1177c7c9a9;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$getPrefix$647af1d6e022a9c4;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$getPrefixes$2ee849be7ba35061;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_gnu_xml_dom_DomNSResolverContext$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNSResolverContext$vmethods {
	struct _jc_java_lang_String$object	*(*getNamespaceURI$1d411b1177c7c9a9)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPrefix$647af1d6e022a9c4)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPrefixes$2ee849be7ba35061)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_gnu_xml_dom_DomNSResolverContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomNSResolverContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNSResolverContext$vmethods	gnu_xml_dom_DomNSResolverContext;
};

// Vtype
struct _jc_gnu_xml_dom_DomNSResolverContext$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNSResolverContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNSResolverContext$sub_refs {
	struct _jc_object	*resolver;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNSResolverContext$refs {
    _jc_gnu_xml_dom_DomNSResolverContext$sub_refs	gnu_xml_dom_DomNSResolverContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNSResolverContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNSResolverContext$sub_nonrefs	gnu_xml_dom_DomNSResolverContext;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNSResolverContext$object {
	_jc_gnu_xml_dom_DomNSResolverContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNSResolverContext$vtype	*vtype;
	_jc_gnu_xml_dom_DomNSResolverContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNSResolverContext$vtype _jc_gnu_xml_dom_DomNSResolverContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNSResolverContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNSResolverContext$class_object;

#endif	/* _JC_gnu_xml_dom_DomNSResolverContext_H_ */
